# Imaging API

## SerialImager

```{eval-rst}
.. automodule:: pclean.imaging.serial_imager
   :members:
   :undoc-members:
   :show-inheritance:
```

## Deconvolver

```{eval-rst}
.. automodule:: pclean.imaging.deconvolver
   :members:
   :undoc-members:
   :show-inheritance:
```

## Normalizer

```{eval-rst}
.. automodule:: pclean.imaging.normalizer
   :members:
   :undoc-members:
   :show-inheritance:
```

## Auto-Masking

```{eval-rst}
.. automodule:: pclean.imaging.automask
   :members:
   :undoc-members:
   :show-inheritance:
```
